@@ -224,7 +224,7 @@ def class_schema(
     >>> @dataclasses.dataclass()
     ... class City:
     ...   name: str = dataclasses.field(metadata={'required':True})
-    ...   best_building: Building # Reference to another dataclasses. A schema will be created for it too.
+    ...   best_building: Building # Reference to another dataclass. A schema will be created for it too.
     ...   other_buildings: List[Building] = dataclasses.field(default_factory=lambda: [])
     ...
     >>> citySchema = class_schema(City)()
@@ -359,7 +359,7 @@ def _field_by_type(
 
 def _field_by_supertype(
     typ: Type,
-    default: marshmallow.missing,
+    default: Any,
     newtype_supertype: Type,
     metadata: dict,
     base_schema: Optional[Type[marshmallow.Schema]],
@@ -451,6 +451,17 @@ def field_for_schema(
         metadata.setdefault("allow_none", True)
         return marshmallow.fields.Raw(**metadata)
 
+    if typing_inspect.is_literal_type(typ):
+        arguments = typing_inspect.get_args(typ)
+        return marshmallow.fields.Raw(
+            validate=(
+                marshmallow.validate.Equal(arguments[0])
+                if len(arguments) == 1
+                else marshmallow.validate.OneOf(arguments)
+            ),
+            **metadata,
+        )
+
     # Generic types
     origin = typing_inspect.get_origin(typ)
     if origin:
@@ -460,13 +471,21 @@ def field_for_schema(
 
         if origin in (list, List):
             child_type = field_for_schema(arguments[0], base_schema=base_schema)
-            list_type = type_mapping.get(List, marshmallow.fields.List)
+            list_type = cast(
+                Type[marshmallow.fields.List],
+                type_mapping.get(List, marshmallow.fields.List),
+            )
             return list_type(child_type, **metadata)
         if origin in (tuple, Tuple):
             children = tuple(
                 field_for_schema(arg, base_schema=base_schema) for arg in arguments
             )
-            tuple_type = type_mapping.get(Tuple, marshmallow.fields.Tuple)
+            tuple_type = cast(
+                Type[marshmallow.fields.Tuple],
+                type_mapping.get(  # type:ignore[call-overload]
+                    Tuple, marshmallow.fields.Tuple
+                ),
+            )
             return tuple_type(children, **metadata)
         elif origin in (dict, Dict):
             dict_type = type_mapping.get(Dict, marshmallow.fields.Dict)
